@@ -19,29 +19,22 @@ developed by KaisaGlobal quant team.
 """
 
 
-import os, sys, json, uuid
+import os, sys, json
 
-import numpy as np
-import pandas as pd
-
-import traceback
 import requests
-#from ws4py.client.threadedclient import WebSocketClient
 import threading
 
 import websocket
 from copy import deepcopy
-import time, codecs
 from pub_cls_com import *
 
 from os.path import dirname, abspath
-
+import socket
 
 project_path = dirname(dirname(abspath(__file__)))
 projec_full_path = project_path + r'\common'
 sys.path.append(projec_full_path)
 
-import csv
 from com import *
 from KaisaCrypto import *
 from utils import *
@@ -50,56 +43,39 @@ from KaisaProtoc import *
 kcrypto = KaisaCrypto()
 kprotoc = KaisaProtoc()
 
-acc_id = 'sz1060'
-acc_id_path = os.getcwd().replace('\\', '/') + '/logger'
-_thisdate_ = datetime.datetime.now().strftime('%Y%m%d')
-##  ## 每十分钟运行一遍【5分钟后退订行情】//每个小时运行一遍【50分钟后退订行情】
-logger_path = r'/{}.csv'.format(datetime.datetime.now().strftime('%Y%m%d'))
-logger_filename = r'logger/_sheet_{}.csv'.format(_thisdate_)
-
-
-
 class KaisaGateway(object):
 
     req_id = 0
-
     # gateway - market, trade;
     gateway_auth_status = False
-
     # ws
     market_ws_alive = False
     trade_ws_alive = False
-
     # trade;
     trade_connect_status = False
     trade_auth_status = False
-
     # token
     gatewayToken = None
     tradeToken = None
-
     _market_ws = None
     _trade_ws = None
 
     _market_connect_status = False
-
     _ws_trade_connect_status = False
-
     _market_connect_msg = ""
 
-    ## 所有字段--dic
-    ## 启动的时候记录接口初始化
-    ## 订阅的时候记录订阅
-    ## 行情推送的时候记录行情
-    ## 退订行情的时候记录退订
-    ## 在退订行情后直接将直接所有记录的数据写入到报表csv中
-    wiki_dict_ = {}
-
     def __init__(self):
         pass
 
-    def jq_user_config(self, user_id, user_pwd, account_code, account_pwd, openapi_token, ip_address=None, environment='paper', callback=None):
-
+    def jq_user_config(self, user_id,
+                       user_pwd,
+                       account_code,
+                       account_pwd,
+                       openapi_token,
+                       ip_address='',
+                       environment='paper',
+                       callback=None):
+        # 构造
         self.user_id = user_id
         self.user_pwd = user_pwd
         self.account_code = account_code
@@ -108,14 +84,45 @@ class KaisaGateway(object):
         self.environment = environment
         self.root_url = KAISA_ROOT_URL_SIM if self.environment in ["simulate", "paper"] else KAISA_ROOT_URL
         self._update_urls()
-
-        self.m_req_id = 0
-        self.trade_req_id = 0
         self.init_api_bool = False
         self.ip_address = ip_address
+        #self.subscribe_code_list = []
+        # AF_INET:ipv4, SOCK_STREAM:tcp
+        self._open_sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         self.subscribe_code_list = []
-        self._market_ws = None
         self.callback_cls = callback
+        self.userid = ''
+        self.gatewayToken = ''
+        self.gateway_auth_status = False
+        self.gateway_auth_msg = ''
+        self.th = None
+        self.file_name = 'logger/heatlog.txt'
+
+    def init_open_md_api(self):
+        # 初始化行情api--TCP>>Login
+
+        if self.gateway_auth_status:
+            return self.gateway_auth_status, self.gateway_auth_msg
+
+        auth_data = self.gateway_auth()
+        use_id = auth_data['userid']
+        token = auth_data['token']
+        ret_ok = auth_data['status']
+        print(f'md_api-开始重连, 更新时间:{datetime.datetime.now()}')
+        # 请求登录和初始化行情api
+        self._open_sock.connect((OPENIP, OPENPORT))
+        self.req_id += 1
+        bs_param = KaisaProtoc.tcp_login(token,
+                                         get_mac_addr(),
+                                         self.ip_address,
+                                         use_id,
+                                         self.req_id)
+        self._open_sock.sendall(bs_param)
+        # 获取服务端返回的数据
+        res_data = self.on_recv()
+        print(f'md_api-连接状态:{res_data}')
+
+        time.sleep(1)
 
     def _update_urls(self):
 
@@ -142,7 +149,7 @@ class KaisaGateway(object):
 
     def _authentica(self, auth_username: str, auth_password: str) -> None:
         """
-        ## websockt 登录
+        ## sockt 登录
         获取网关登录令牌;
         :param auth_username:
         :param auth_password:
@@ -150,134 +157,133 @@ class KaisaGateway(object):
         """
 
         if self.gateway_auth_status:
-            return self.gateway_auth_status, self.gateway_auth_msg
+            return {'status': self.gateway_auth_status, 'msg': self.gateway_auth_msg, 'token': self.gatewayToken, 'userid': self.userid}
+        gateway_auth_msg = ""
 
-        # only for token of gateway.
-        timestamp_ = generate_timestamp()
-        sign_ = kcrypto.encrypt_md5("username{}Timestamp{}".format(auth_username, timestamp_))
+        try:
+            # only for token of gateway.
+            timestamp_ = generate_timestamp()
+            sign_ = kcrypto.encrypt_md5("username{}Timestamp{}".format(auth_username, timestamp_))
 
-        auth_username_encrypt = kcrypto.encrypt_rsa_username(auth_username, crypto_rsa_url=self.CRYPTO_RSA_URL)
-        auth_password_encrypt = kcrypto.encrypt_aes_password(auth_password, "MAKRET")
+            auth_username_encrypt = kcrypto.encrypt_rsa_username(auth_username, crypto_rsa_url=self.CRYPTO_RSA_URL)
+            auth_password_encrypt = kcrypto.encrypt_aes_password(auth_password, "MAKRET")
 
-        params = {
-            "username": auth_username_encrypt,
-            "password": auth_password_encrypt,
-            "grant_type": "password",
-            "scope": openapi_scope
-        }
+            params = {
+                "username": auth_username_encrypt,
+                "password": auth_password_encrypt,
+                "grant_type": "password",
+                "scope": openapi_scope
+            }
 
-        ipAddress = self.ip_address
-        if ipAddress:
-            params["ipAddress"] = ipAddress
+            ipAddress = self.ip_address
+            if ipAddress:
+                params["ipAddress"] = ipAddress
 
-        headerParam = {"srvType": "open", "ipAddress": ipAddress, "phoneModel": "",
-                       "deviceId": "", "deviceToken": "", "macAddress": get_mac_addr(),
-                       "channelId": "", "country": "", "sysVersion": "",
-                       "apiVersion": "", "platform": ""}
-        headerParam = json.dumps(headerParam)
+            headerParam = {"srvType": "open", "ipAddress": ipAddress, "phoneModel": "",
+                           "deviceId": "", "deviceToken": "", "macAddress": get_mac_addr(),
+                           "channelId": "", "country": "", "sysVersion": "",
+                           "apiVersion": "", "platform": ""}
+            header_userid_param = {"platform": "web"}
+            headerParam = json.dumps(headerParam)
+            header_userid_param = json.dumps(header_userid_param)
+            authorization_str = "basic {}".format(self.openapi_token)
+            headers = {
+                "Authorization": authorization_str,
+                "Content-Type": "application/x-www-form-urlencoded",
+                "Sign": sign_,
+                "Timestamp": timestamp_,
+                "headerParam": headerParam
+            }
 
-        authorization_str = "basic {}".format(self.openapi_token)
-        headers = {
-            "Authorization": authorization_str,
-            "Content-Type": "application/x-www-form-urlencoded",
-            "Sign": sign_,
-            "Timestamp": timestamp_,
-            "headerParam": headerParam
-        }
+            response = requests.post(url=self.AUTHENTICA_URL, params=params, headers=headers)
 
-        response = requests.post(
-            url=self.AUTHENTICA_URL, params=params, headers=headers
-        )
-
-        self.gateway_auth_msg = ""
-
-        data = response.json()
-        if response.status_code // 100 == 2:
-            self.write_log("网关认证成功")
-            if data['success']:
-                self.write_log("获取登录令牌成功")
-                token_body = data["body"]["accessToken"]
-                self.gatewayToken = f"bearer {token_body}"
-                self.token = self.gatewayToken
-                self.gateway_auth_status = True
+            data = response.json()
+            if response.status_code // 100 == 2:
+                # get_userid-url
+                self.write_log("网关认证成功")
+                if data['success']:
+                    self.write_log("获取登录令牌成功")
+                    __, ___ = self._get_accessToken(data)
+                    __gatewayToken__ = __
+                    gateway_auth_status = ___
+                    __userid__ = self._get_user_info(__, header_userid_param)
+                else:
+                    self.token = None
+                    self.write_log("获取登录令牌失败")
+                    self.write_error(data)
+                    gateway_auth_status = False
+                    gateway_auth_msg = None
+                    __userid__ = None
+                    __gatewayToken__ = None
             else:
-                self.token = None
-                self.gatewayToken = None
-                self.write_log("获取登录令牌失败")
+                self.write_log("网关认证失败")
                 self.write_error(data)
-        else:
-            self.write_log("网关认证失败")
-            self.write_error(data)
+                gateway_auth_status = False
+                gateway_auth_msg = None
+                __userid__ = None
+                __gatewayToken__ = None
 
-        return self.gateway_auth_status, self.gateway_auth_msg
+            self.gatewayToken = __gatewayToken__
+            self.gateway_auth_msg = gateway_auth_msg
+            self.gateway_auth_status = gateway_auth_status
+            self.userid = __userid__
+
+        except Exception as expp:
+            self.write_log("网关认证失败, err:{}".format(expp))
+            gateway_auth_status = self.gateway_auth_status
+            gateway_auth_msg = self.gateway_auth_msg
+            __userid__ = self.userid
+            __gatewayToken__ = self.gatewayToken
+
+        return {'status': gateway_auth_status, 'msg': gateway_auth_msg, 'token': __gatewayToken__, 'userid': __userid__}
+
+    def _get_user_info(self, token, header_userid_param):
+        # 获取user-msg
+        headers_userid = {
+            "Authorization": 'bearer ' + token,
+            "headerParam": header_userid_param
+        }
+        UA_URL = AU_USERID_URL.replace('__kaisarooturl__', self.root_url)
+        response_userid = requests.post(url=UA_URL, headers=headers_userid)
+
+        if response_userid.status_code // 100 == 2:
+            userid_data = response_userid.json()
+            user_id_num = userid_data['body']['userId']
+
+        else:
+            user_id_num = ''
+        return user_id_num
+
+    def _get_accessToken(self, data):
+        # 获取登录令牌
+        try:
+            token_body = data["body"]["accessToken"]
+            #gatewayToken = f"bearer {token_body}"
+            gateway_auth_status = True
+        except Exception as exp:
+            print('获取登录令牌抛异常:{}'.format(exp))
+            token_body = ''
+            gateway_auth_status = False
+        return token_body, gateway_auth_status
 
     def gateway_auth(self):
         return self._authentica(self.user_id, self.user_pwd)
 
-    def _mkfile(self, filename):
-        # 判断文件是否存在，不存在就创建
-        headers = ['update_time', 'id', 'is_sub', 'is_gateway_auth', 'is_init_api', 'is_un_sub', 'is_quote_arrive',
-                   'is_quote_right', 'tick_res_time', 'quote_res_time', 'broker_res_time', 'level_order_res_time',
-                   'is_api_error']
-        with open(filename, mode='w', encoding='UTF-8') as ff:
-            employee_writer = csv.writer(ff, delimiter=',', quotechar='"', quoting=csv.QUOTE_MINIMAL)
-            employee_writer.writerow(headers)
-
-    def _mkdir(self, path):
-        # 判断文件夹是否存在，不存在就创建
-        if not os.path.exists(path):
-            os.mkdir(path)
-
-    def _make_file(self, filename):
-        # 建文件[如果文件不存在，建文件]
-        ff = open(filename, mode='w', encoding='UTF-8')
-        ff.close()
-
-    def _read_file(self, filename):
-        # 读取文件
-        df = pd.read_csv(filename)
-        return df
-
-    def _write_file(self, filename, data):
-        ## 追加写入文件
-        fs = open(filename, mode='a', encoding='utf-8')
-        fs.write(data)
-        fs.close()
-
     def init_md_api(self):
         '''
         初始化mdApi
         --login并验证行情账号
         --初始化行情Api
         '''
-
         try:
-            self.wiki_dict_['id'] = 'sz1057'
-            ## 判断文件夹是否存在，不存在就创建
-            #self._mkdir(acc_id_path)
-            ## 判断文件是否存在，不存在就创建
-            self._make_file(logger_filename)
-            ret_ok, ret_msg = self.gateway_auth()
+            data = self.gateway_auth()
+            ret_msg = data['msg']
+            ret_ok = data['status']
             if ret_ok:
                 print('行情账号登录成功!')
                 self.init_api_bool = ret_ok
-                self.wiki_dict_['is_gateway_auth'] = 'True'
-                self.wiki_dict_['is_api_error'] = 'False'
             else:
-                self.wiki_dict_['is_gateway_auth'] = 'False'
                 print('行情账号登录失败,error:{}!'.format(ret_msg))
-                ## -- 把行情推送中触发的异常写入log文档中[正常/失败]
-        except Exception as exp:
-            ## -- 把行情推送中触发的异常写入log文档中[正常/失败]
-            self.wiki_dict_['is_gateway_auth'] = 'False'
-            return 'market-ws disconnected!', exp
-
-    def market_connect_ws(self):
-        # connect ws
-        try:
-            if self.init_api_bool:
-                self.market_connect_ws0()
-
         except Exception as exp:
             return 'market-ws disconnected!', exp
 
@@ -371,293 +377,54 @@ class KaisaGateway(object):
             symbols = None
         return symbols
 
-    def query_history_kline(self, symbol='01638', market='HK', klinetype='1d', adjfactortype='0', pagenum=1, pagesize=100):
-        """
-        query history kline (only for hk market)
-        """
-        post_url = MARKET_POST_URL+"/quoteInfo/kLine"
-
-        klinetype2klineid = {'1min': 1,
-                             '5min': 3,
-                             '15min': 5,
-                             '30min': 6,
-                             '1hour': 7,
-                             '1d': 10
-                             }
-        klineid = klinetype2klineid.get(klinetype)
-        rqdata = {
-            'code': symbol,
-            'market': market,
-            'quoteTypeEnumCode': klineid,
-            'adjFactorType': adjfactortype,
-            'pageNum': pagenum,
-            'pageSize': pagesize
-        }
-        response = requests.request(
-            'POST',
-            post_url,
-            headers={'Content-Type':'application/json'},
-            params=None,
-            data=json.dumps(rqdata)
-        )
-        status_code = response.status_code
-        resp_data = response.json()
-        resp_status = resp_data['success']
-        if resp_status:
-            body_data = resp_data['body']['records']
-        else:
-            body_data = {
-                'retCode': resp_data['retCode'],
-                'retMsg': resp_data['retMsg']
-                }
-        return resp_status, body_data
-
-    def get_history_kline_data(self, symbol=['00700'], start_date=None, end_date=None, unit='1d', market=1, fre='pre'):
-       '''
-       Args:
-            symbol: 合约列表 list
-            market: 市场类型：1 CH/ 2 HK/ 3 USA
-            unit: 频率 默认为 '1d' 将支持如下周期: '1m', '5m', '15m', '30m', '1d', '1w', '1M'. '1w' 表示一周, '1M' 表示一月
-            start_date: 开始日期
-            end_date: 结束日期
-            fre:是否复权  1 不复权/2 前复权/3 后复权
-        Returns: 返回历史日K/分钟K数据
-       '''
-        # /stock/quote/tickHistory/v2
-        # quoteInfo/kLineHistory/v2
-       post_url = HK_STOCK_KLINE_POST_URL
-       if unit != '1m' or unit != '1d':return '您好, 该接口暂时只提供日K和1分钟K线数据, 其他频率的数据, 接口维护团队会尽快补上!'
-       if unit == '1m':
-           if len(symbol) >1:return '您好, 检测到您填入多个合约获取历史分钟k线, 请修改后重新请求数据!'
-       if start_date is None and end_date is None:return '您好, 检测到您填入两个为None的日期, 请修改后重新请求数据!'
-       if market != 1:return '您好, 该接口暂时只提供港股数据, 请修改后重新请求数据!'
-       kprotoc.get_kline_hist_data_proto()
-
-    def query_history_tick(self, symbol='00700', market='HK', pagesize=10, pagenum=1):
-
-        post_url = MARKET_POST_URL + "/stock/quote/tick"
-        rqdata = {
-            'code': symbol,
-            'market': market,
-            'size': str(pagesize),
-            'index': str(pagesize*pagenum)
-        }
-        response = requests.request(
-            'POST',
-            post_url,
-            headers={'Content-Type': 'application/json'},
-            params=None,
-            data=json.dumps(rqdata)
-        )
-        status_code = response.status_code
-        resp_data = response.json()
-        resp_status = resp_data['success']
-        if resp_status:
-            body_data = resp_data['body']
-        else:
-            body_data = {'retCode': resp_data['retCode'],
-                         'retMsg': resp_data['retMsg']
-                         }
-        return resp_status, body_data
-
-    def query_detailstate(self, symbol='01638', market=2):
-        # detailstate
-        post_url = MARKET_POST_URL + "/quoteInfo/todayDetailState"
-        rqdata = {
-            'code': symbol,
-            'market': Quote_MARKET_DICT[market],
-            'hasQuoteInfo': True,
-            'hasQuoteExt': True,
-            'hasQuoteStat': True,
-            'hasQuoteFinancial': True,
-            'hasQuotePro': True
-        }
-        response = requests.request(
-            'POST',
-            post_url,
-            headers={'Content-Type': 'application/json', 'headerParam': json.dumps({'apiVersion': "1.2.0"})},
-            params=None,
-            data=json.dumps(rqdata)
-        )
-        status_code = response.status_code
-        resp_data = response.json()
-        resp_status = resp_data['success']
-        if resp_status:
-            body_data = resp_data['body']
-            del body_data['assetInfoResp']
-        else:
-            body_data = {'retCode': resp_data['retCode'],
-                         'retMsg': resp_data['retMsg']
-                         }
-        return resp_status, body_data
-
-    def market_connect_ws0(self):
-        threading.Thread(target=self.__market_connect_ws, daemon=True).start()
-        time.sleep(3)
-
     def get_market_connect_ws_status(self):
 
         return self._market_connect_status, self._market_connect_msg
 
-    def _on_message(self, ws, message) -> None:
-        # ws消息回报
-        #("### on_message ###")
-        self.req_id += 1
-        if message is None or message == '':
-            return
-        try:
-            self.wiki_dict_['is_quote_arrive'] = 'True'
-            data = kprotoc.rec_bstring_to_json(message)   # 把字符串转换为json数据类型
-            if data is None:
-                pass
-            elif data['data'] is not None:
-                self.callback_cls(data)
+    def on_recv(self):
+        # recv
+        res_data = self._open_sock.recv(1024)
+        return res_data
 
-                ##################################
-                self.wiki_dict_['is_quote_right'] = 'True'
-                if data['type'] == 'TICK':
-                    if 'tick_res_time' not in self.wiki_dict_:
-                        self.wiki_dict_['tick_res_time'] = [datetime.datetime.now()]
-                    else:
-                        tick_time_list = list(self.wiki_dict_['tick_res_time'])
-                        tick_time_list.append(datetime.datetime.now())     ## time.time()
-                        self.wiki_dict_['tick_res_time'] = tick_time_list
+    def on_message(self):
+        # get-data
+        while True:
+            try:
+                message = self.on_recv()
+                # 把字符串转换为json数据类型
+                data = kprotoc.rec_bstring_to_json(message)
+                if data is None:
+                    pass
+                elif data['data'] is not None:
+                    #  回调函数
+                    self.callback_cls(data)
+            except Exception as expp:
+                continue
 
-                if data['type'] == 'QUOTE':
-                    if 'quote_res_time' not in self.wiki_dict_:
-                        self.wiki_dict_['quote_res_time'] = [datetime.datetime.now()]
-                    else:
-                        # print('quote_res_time:{}'.format(self.wiki_dict_['quote_res_time']))
-                        # print('quote_res_time--now:{}'.format(time.time()))
-                        quote_time_list = list(self.wiki_dict_['quote_res_time'])
-                        quote_time_list.append(datetime.datetime.now())
-                        self.wiki_dict_['quote_res_time'] = quote_time_list
-
-                if data['type'] == 'BROKER':
-                    if 'broker_res_time' not in self.wiki_dict_:
-                        self.wiki_dict_['broker_res_time'] = [datetime.datetime.now()]
-                    else:
-                        broker_time_list = list(self.wiki_dict_['broker_res_time'])
-                        broker_time_list.append(datetime.datetime.now())
-                        self.wiki_dict_['broker_res_time'] = broker_time_list
-                if data['type'] == 'ORDER':
-                    if 'level_order_res_time' not in self.wiki_dict_:
-                        self.wiki_dict_['level_order_res_time'] = [datetime.datetime.now()]
-                    else:
-                        order_time_list = list(self.wiki_dict_['level_order_res_time'])
-                        order_time_list.append(datetime.datetime.now())
-                        self.wiki_dict_['level_order_res_time'] = order_time_list
-                ##################################
-
-        except Exception as exp:
-            self.wiki_dict_['is_quote_right'] = 'False'
-            print('on-message-cls error:{}'.format(exp))
-            ## -- 把行情推送中触发的异常写入log文档中[正常/失败]
-            pass
-
-    def _on_error(self, ws, error) -> None:
-        # ws异常回报--把接口触发的异常写入log文档中[正常/失败]
-        self.wiki_dict_['is_api_error'] = 'True'
-        print(f'ws异常回报，error:{error}')
-
-    def _on_close(self, ws, close_status_code, close_msg) -> None:
-        # ws关闭连接(closed)回报
-        self.wiki_dict_['is_api_abnormal_close'] = 'True'
-        print(f"ws已关闭>> close_msg:{close_msg}!")
-
-    def _on_open(self, ws) -> None:
-        # ws open-sub
+    def _on_sub(self, subscribe_code_list):
+        # open-sub
         print("####### on_sub #######")
         def run(*args):
-            time.sleep(1)
+
             self.req_id += 1
-            sub_bstring = kprotoc.get_subscribe_bstring(self.subscribe_code_list, self.req_id)
-            self._market_ws.sock.send_binary(sub_bstring)
+            sub_bstring = kprotoc.get_subscribe_bstring(subscribe_code_list, self.req_id)
+            rd = self._open_sock.sendall(sub_bstring)
             time.sleep(1)
         try:
             run()
-            th = threading.Thread(target=self._market_ping, args=())
-            th.start()
-            self.wiki_dict_['is_sub'] = 'True'
+            self.subscribe_code_list = subscribe_code_list
+            # 发心跳
+            self.th = threading.Thread(target=self._market_ping, args=())
+            self.th.start()
+
+            # 获取数据
+            th_msg = threading.Thread(target=self.on_message, args=())
+            th_msg.start()
+
         except Exception as exp:
-            ## -- 把每次订阅的行为结果写入log文档中[正常/失败]
             print('on-open--error:{}'.format(exp))
-            self.wiki_dict_['is_sub'] = 'False'
             pass
 
-    def __market_connect_ws(self):
-
-        if self._market_connect_status:
-            return
-        # header = {"Authorization": self.gatewayToken,
-        #           "deviceId":"xxx",
-        #           "platform":"open",
-        #           "srvType":"open"}
-
-        data = {"deviceId": "xxx",
-                "platform": "open",
-                "srvType": "open"}
-
-        header = {"Authorization": self.gatewayToken,
-                  "headerParam": json.dumps(data)}
-
-        try:
-            ######################new++++++++++++++++++
-            #websocket.enableTrace(True)
-            self._market_ws = websocket.WebSocketApp(
-                url=MARKET_WS_URL,
-                header=header,
-                on_open=self._on_open,
-                on_message=self._on_message,
-                on_error=self._on_error,
-                on_close=self._on_close)
-
-            #self._market_ws.on_open = self._on_open   # # ws open-ping
-            self._market_connect_msg = ""
-
-            try:
-                self.wiki_dict_['is_init_api'] = 'True'
-                self._market_ws.run_forever()
-            except Exception as exp:
-                ## --把每次连接行情接口的操作结果写入log文档中[正常/失败]
-                print('__market_connect_ws:exp:{}'.format(exp))
-                self.wiki_dict_['is_init_api'] = 'False'
-                pass
-            ######################new++++++++++++++++++
-
-
-            ################旧版################
-            # self._market_ws = websocket.create_connection(MARKET_WS_URL, header=header)
-            # print('ws连接状态:{}'.format(self._market_ws.status))
-            # print('ws连接connected:{}'.format(self._market_ws.connected))
-            # # self._market_ping_th = threading.Thread(target=self._market_ping, args=(self._market_ws,), daemon=True)
-            # # self._market_ping_th.start()
-            # self._market_connect_status = self._market_ws.connected
-            # self._market_connect_msg = ""
-            # time.sleep(5)
-            # ret_status, ret_data = self.get_market_connect_ws_status()
-            # if ret_status:
-            #     print("market-ws connected!")
-            # else:
-            #     print('market-ws disconnected, error:{}'.format(ret_data))
-            # while True:
-            #     print('_market_ws--> recv >> ')
-            #     text = self._market_ws.recv()              # 接口实时返回的字符串
-            #     print('__market_connect_ws >> text:{}'.format(text))
-            #     if text is None or text == '':
-            #         continue
-            #     data = kprotoc.rec_bstring_to_json(text)   # 把字符串转换为json数据类型
-            #     if data is None:
-            #         continue
-            #
-            #     self.on_market_data(data)
-            #################旧版################
-        except Exception as exp:
-            ## --把每次连接行情接口的操作结果写入log文档中[正常/失败]
-            print('WebSocket Connection Status:{}'.format(self._market_ws.sock))
-            print('market-ws disconnected, error:{}'.format(exp))
-            self.wiki_dict_['is_init_api'] = 'False'
-
     def on_market_packet(self, packet):
         self.on_market_data(packet)
 
@@ -670,24 +437,9 @@ class KaisaGateway(object):
         订阅quote和tick数据
         code_list: [{'code':'01638', 'market':2, 'sub_type':2}]
         """
-
-        sub_types = [data['sub_type'] for data in code_list]
-        sub_types = list(set(sub_types))
-        if QUOTE in sub_types:
-            self.wiki_dict_['quote_res_time'] = [datetime.datetime.now()]  # time.time()
-
-        if TICK in sub_types:
-            self.wiki_dict_['tick_res_time'] = [datetime.datetime.now()]
-
-        if LEVEL_ORDER in sub_types:
-            self.wiki_dict_['level_order_res_time'] = [datetime.datetime.now()]
-
-        if BROKERS in sub_types:
-            self.wiki_dict_['broker_res_time'] = [datetime.datetime.now()]
-
-        self.subscribe_code_list = code_list
         self.req_id += 1
-        self.market_connect_ws0()
+        # 订阅
+        self._on_sub(code_list)
 
     def unsubscribe_marketdata(self, code_list):
         """
@@ -698,13 +450,10 @@ class KaisaGateway(object):
         try:
             self.req_id += 1
             bstring = kprotoc.get_unsubscribe_bstring(code_list, self.req_id)
-            self._market_ws.sock.send_binary(bstring)
-            self.wiki_dict_['is_un_sub'] = 'True'
+            self._open_sock.sendall(bstring)
         except Exception as exp:
-            ## --把每次退订行情的操作结果写入log文档中[正常/失败]
-            self.wiki_dict_['is_un_sub'] = 'False'
             pass
-        self.wiki_dict_['update_time'] = datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S')
+
 
     def _market_ping(self):
         """
@@ -712,23 +461,35 @@ class KaisaGateway(object):
         :return:
         """
         while True:
-            self.market_heartbeat()
-            time.sleep(5)
+            _now_ = datetime.datetime.now()
+            try:
+                with open(self.file_name, 'a') as fs:
+                    mytxt = '发送心跳:{}'.format(_now_) + ', ' + '线程状态:{}'.format(self.th.is_alive()) + '.\n'
+                    fs.write(mytxt)
+                self.market_heartbeat()
+                time.sleep(5)
+            except Exception as exp:
+                with open(self.file_name, 'a') as fs:
+                    mytxt = '发送心跳:{}'.format(_now_) + ', 出现异常:'.format(exp) + ', ' + '线程状态:{}'.format(self.th.is_alive()) + '.\n'
+                    fs.write(mytxt)
+                # 断开
+                self._open_sock.close()
+                self.gateway_auth_status = False
+                # api 重连
+                self.init_open_md_api()
+                # 重新订阅行情
+                self.subscribe_marketdata(self.subscribe_code_list)
+                time.sleep(5)
 
     def market_heartbeat(self):
-
+        # 心跳
         self.req_id += 1
-
         ping_bstring = kprotoc.get_ping_bstring(self.req_id)
-
-        self._market_ws.sock.send_binary(ping_bstring)
-
-        #self._market_ws.send_binary(ping_bstring)
+        self._open_sock.sendall(ping_bstring)
 
     def send_market_packet(self, packet):
-
         text = json.dumps(packet)
-        self._market_ws.send(text)
+        #self._open_sock.send(text)
 
     def generate_req(self, reqtype: int, data: dict) -> dict:
 
@@ -916,7 +677,8 @@ class KaisaGateway(object):
         交易连接
         :return: trade_connect_status
         """
-        if self.gateway_auth():
+        ret_ok, ret_msg, rt_userid, rt_token = self.gateway_auth()
+        if ret_ok:
             en_password_trade = kcrypto.encrypt_aes_password(self.account_pwd, type="TRADE")
             self.en_password_trade = en_password_trade
             secret_q = kcrypto.encrypt_rsa_secretQ(crypto_rsa_url = self.TRADE_CRYPTO_RSA_URL)
@@ -963,7 +725,6 @@ class KaisaGateway(object):
     def get_trade_connect_ws_status(self):
         return self._ws_trade_connect_status, ""
 
-
     def _trade_ping(self, this_ws):
         """
         :param this_ws:
