@@ -1,12 +1,12 @@
 # -*- coding: utf-8 -*-
 
-import sys, json, time
+import sys, json, time, struct
 from os.path import dirname, abspath
-
+from google.protobuf import json_format
 project_path = dirname(dirname(abspath(__file__)))
 projec_full_path = project_path + r'\py_protoc'
 sys.path.append(projec_full_path)
-import socket
+from pub_cls_com import *
 from com import *
 ############################旧版################################
 # from py_protoc import msg_stock_pb2 as msg_stock
@@ -26,15 +26,71 @@ class KaisaProtoc(object):
         pass
 
     @staticmethod
-    def get_ping_bstring(reqId=1):
+    def tcp_login(token, macip, ip, userid, reqid):
+        # tcp 登录、初始化行情api
+        pb_login = comm_pb.Login()
+        pb_login.token = token
+        pb_login.deviceId = macip
+        pb_login.macAddress = macip
+        pb_login.ipAddress = ip
+        pb_login.sysVersion = SYSVERSION
+        pb_login.platform = PLATFORM
+        pb_login.phoneModel = PHONEMODEL
+        pb_login.srvType = SRVTYPE
+        pb_login.username = EP
+        pb_login.password = EP
+        pb_login.userId = userid
+        pb_string = pb_login.SerializeToString()
+        return KaisaProtoc.get_reqhead(20, 0, pb_string, reqid)
 
-        pb_reqhead = msg_stock_common.ReqHead()
-        pb_reqhead.reqId = reqId
-        pb_reqhead.mod = 3
-        # pb_reqhead.len = 0
-        # pb_reqhead.data = ""
-        #pb_reqhead.reqType = 3
-        pb_string = pb_reqhead.SerializeToString()
+    @staticmethod
+    def get_head_bstring():
+        #  通讯头
+        packFlag = struct.pack('>h', 2021)
+        iCompress = struct.pack('>h', 0)
+        iVersion = struct.pack('>h', 0)
+        iReserve = struct.pack('>i', 0)
+        iCheckId = struct.pack('>h', 1990)
+        head_bstrin = packFlag + iCompress + iVersion + iReserve + iCheckId
+        return head_bstrin
+
+    @staticmethod
+    def get_cust_head_bstring():
+        #cust_head
+        cust_c = cust_pb.CustHead()
+        cust_c.packFlag = 2021
+        cust_c.iCompress = 0
+        cust_c.iVersion = 0
+        cust_c.iReserve = 0
+        cust_c.iCheckId = 1990
+        return cust_c
+
+    @staticmethod
+    def get_reqhead(mod, cmd, data, reqid=None):
+        # 请求头
+        if reqid is not None:
+            reqId = struct.pack('>i', reqid)
+        else:
+            reqId = 0
+        # 心跳
+        if mod == 3:
+            data = b'0'
+        mod = struct.pack('>h', mod)
+        cmd = struct.pack('>h', cmd)
+        datalen = struct.pack('>i', len(data))
+        reqhead = KaisaProtoc.get_head_bstring() + reqId + mod + cmd + datalen
+        result = reqhead + data
+        return result
+    @staticmethod
+    def get_reshead(data):
+        #
+        res = KaisaProtoc.get_head_bstring() + data
+        return res
+
+    @staticmethod
+    def get_ping_bstring(reqId=1):
+        # 心跳
+        pb_string = KaisaProtoc.get_reqhead(3, 0, b'0', reqId)
         return pb_string
 
     @staticmethod
@@ -47,7 +103,6 @@ class KaisaProtoc(object):
         BROKER = 3;
         ORDER = 4;
         '''
-
         pb_rule = msg_stock.Rule()
         #pb_stockcode = msg_stock.StockCode()
         for secucode_dict in symbollist:
@@ -57,17 +112,11 @@ class KaisaProtoc(object):
             pb_stockcode_one.market = market
             pb_stockcode_one.language = 0
             pb_stockcode_one.types.append(secucode_dict['sub_type'])
-        #pb_rule.types.append(1)
-        #pb_rule.types.append(2)
-        ps = pb_rule.SerializeToString()
-        pb_reqhead = msg_stock_common.ReqHead()
-        pb_reqhead.reqId = reqId
-        pb_reqhead.mod = 1
-        pb_reqhead.cmd = 10   # SubQuote
-        pb_reqhead.len = len(ps)
-        pb_reqhead.data = ps
-        pb_string = pb_reqhead.SerializeToString()
 
+        ps = pb_rule.SerializeToString()
+        mod = 1
+        cmd = 10
+        pb_string = KaisaProtoc.get_reqhead(mod, cmd, ps, reqId)
         return pb_string
 
     @staticmethod
@@ -80,6 +129,8 @@ class KaisaProtoc(object):
         BROKER = 3;
         ORDER = 4;
         '''
+        mod = 1
+        cmd = 11
         pb_rule = msg_stock.Rule()
         pb_stockcode = msg_stock.StockCode()
         for secucode_dict in symbollist:
@@ -89,16 +140,9 @@ class KaisaProtoc(object):
             pb_stockcode_one.market = market
             pb_stockcode_one.language = 0
             pb_stockcode_one.types.append(secucode_dict['sub_type'])
-        # pb_rule.types.append(1)
-        # pb_rule.types.append(2)
         ps = pb_rule.SerializeToString()
-        pb_reqhead = msg_stock_common.ReqHead()
-        pb_reqhead.reqId = reqId
-        pb_reqhead.mod = 1
-        pb_reqhead.cmd = 11  # UnSubQuote
-        pb_reqhead.len = len(ps)
-        pb_reqhead.data = ps
-        pb_string = pb_reqhead.SerializeToString()
+
+        pb_string = KaisaProtoc.get_reqhead(mod, cmd, ps, reqId)
         return pb_string
 
     @staticmethod
@@ -108,23 +152,28 @@ class KaisaProtoc(object):
         {QUOTE = 1;
         TICK = 2;
         }
-
         bytes data = 7; //二进制数据 4位
+
+        # '!'表示我们用网络字节序解析,因为我们是从网络上接收到这个buf的。
+        # 'H'表示unsigned short的id；
+        # '4s'表示四个字节长的字符串； char[4]
+        # '2I'表示有两个unsigned int类型的数据；
         '''
 
         data_type = 0
         try:
-            pb_reshead = reponse_pb.ResHead()
-            pb_reshead.ParseFromString(bstring)
-            if pb_reshead.cmd not in ALLDATAIDLIST:
-                pass
+            if len(bstring) >= 28:
+                cmd, __ = get_respdata(bstring)
+                if __ == '' or cmd not in ALLDATAIDLIST:
+                    return {'type': 0, 'data': None}
+                else:
+                    data_type, res_data = KaisaProtoc.handle_any_data_cls(cmd, __)
+                    return {'type': data_type, 'data': res_data}
             else:
-                data_type, res_data = KaisaProtoc.handle_any_data_cls(pb_reshead.cmd, pb_reshead.data)
-
-                return {'type': data_type, 'data': res_data}
-        except Exception as exp:
-            res_data = exp
-            return {'type': data_type, 'data': res_data}
+                return {'type': 0, 'data': None}
+        except BaseException as exp:
+            print('获取行情抛异常:{}'.format(exp))
+            return {'type': data_type, 'data': None}
 
 
     @staticmethod
@@ -190,6 +239,7 @@ class KaisaProtoc(object):
     @staticmethod
     def level_order_list_string_to_json(order_list):
         # level_order list data
+
         return {'market': order_list.market,
                 'code': order_list.code,
                 'time': time.strftime("%Y-%m-%d %H:%M:%S", time.localtime(
@@ -229,23 +279,21 @@ class KaisaProtoc(object):
     def _get_tick_data(data):
         #### cmd=2
         #### 逐笔数据 tick
-        ticklist = msg_stock.TickList()
-        ticklist.ParseFromString(data)
-        body_json = KaisaProtoc.ticklist_bstring_to_json(ticklist)
+
+        body_json = KaisaProtoc.ticklist_bstring_to_json(data)
         return PROTODATADIC[TICK], body_json
 
     @staticmethod
     def _get_quote_data(data):
         #### cmd=1
         #### 盘口数据 quote
-        quote = msg_stock.Quote()
-        quote.ParseFromString(data)
+
         try:
             ## 判断该条行情是否有效
-            if quote.update_flag != [1, 4, 8, 16, 32, 2048, 32768]:
+            if data.update_flag != [1, 4, 8, 16, 32, 2048, 32768]:
                 return QUOTE, None
             else:
-                body_json = KaisaProtoc.quote_bstring_to_json(quote)
+                body_json = KaisaProtoc.quote_bstring_to_json(data)
                 return PROTODATADIC[QUOTE], body_json
         except Exception as exp:
             print('get-quote-data-error:{}'.format(exp))
@@ -254,18 +302,14 @@ class KaisaProtoc(object):
     def _get_broker_data(data):
         #### cmd=3
         #### 经纪商数据 broker-list
-        broker_list = msg_stock.BrokerList()
-        broker_list.ParseFromString(data)
-        body_json = KaisaProtoc.broker_list_bstring_to_json(broker_list)
+        body_json = KaisaProtoc.broker_list_bstring_to_json(data)
         return PROTODATADIC[BROKERS], body_json
 
     @staticmethod
     def _get_level_order_data(data):
         ### cmd=4
         ### level-10 order data
-        order_list = msg_stock.OrderStallsList()
-        order_list.ParseFromString(data)
-        body_json = KaisaProtoc.level_order_list_string_to_json(order_list)
+        body_json = KaisaProtoc.level_order_list_string_to_json(data)
         return PROTODATADIC[LEVEL_ORDER], body_json
 
 if __name__=='__main__':
